Welcome to Tamarco's documentation!
===================================

.. toctree::

   README
   tutorials/main
   how_to_guides/main
   explanations/main
   reference/main
   develop/main
   CONTRIBUTING
   CODE_OF_CONDUCT

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
